==> clean_calendar-0.0.1-dev.3.tar.gz: lib/src/ui/grid_view_element.dart <==
import 'package:clean_calendar/src/state/providers.dart';
import 'package:clean_calendar/src/utils/get_suitable_calendar_general_date_widget.dart';
import 'package:clean_calendar/src/utils/get_suitable_calendar_streak_date_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class CalendarDateWidget extends StatelessWidget {
  const CalendarDateWidget(
      {Key? key,
      required this.pageViewElementDate,
      required this.pageViewMonthDate})
      : super(key: key);

  final DateTime pageViewElementDate;
  final DateTime pageViewMonthDate;

  @override
  Widget build(BuildContext context) {
    return Consumer(
      builder: (BuildContext context, WidgetRef ref, Widget? child) {
        final Widget dateSuitableWidgetProviderValue = ref
            .watch(dateSuitableWidgetProvider(IndividualDateElementProperties(
          pageViewElementDate: pageViewElementDate,
          pageViewMonthDate: pageViewMonthDate,
        )).select((value) => value));

        Widget calendarDateWidget = dateSuitableWidgetProviderValue;
        return calendarDateWidget;
      },
    );
  }
}

Widget getSuitableCalendarDateWidget(
    {required bool enableDenseViewForDates,
    required bool enableDenseSplashForDates,
    required DateTime pageViewElementDate,
    required DateTime pageViewMonthDate,
    required List<DateTime> datesForStreaks}) {
  if (datesForStreaks.contains(pageViewElementDate)) {
    return getSuitableCalendarStreakDateWidget(
        enableDenseViewForDates: enableDenseViewForDates,
        enableDenseSplashForDates: enableDenseSplashForDates,
        pageViewElementDate: pageViewElementDate,
        pageViewMonthDate: pageViewMonthDate,
        datesForStreaks: datesForStreaks);
  }
  if (!datesForStreaks.contains(pageViewElementDate)) {
    return getSuitableCalendarGeneralDateWidget(
        enableDenseViewForDates: enableDenseViewForDates,
        enableDenseSplashForDates: enableDenseSplashForDates,
        pageViewElementDate: pageViewElementDate,
        pageViewMonthDate: pageViewMonthDate);
  } else {
    return const SizedBox();
  }
}

==> clean_calendar-0.2.0-dev.2.tar.gz: lib/src/ui/grid_view_element.dart <==
import 'package:clean_calendar/src/state/properties_state.dart';
import 'package:clean_calendar/src/state/providers.dart';
import 'package:clean_calendar/src/utils/get_suitable_calendar_general_date_widget.dart';
import 'package:clean_calendar/src/utils/get_suitable_calendar_streak_date_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class CalendarDateWidget extends StatelessWidget {
  const CalendarDateWidget(
      {Key? key,
      required this.pageViewElementDate,
      required this.pageViewMonthDate})
      : super(key: key);

  final DateTime pageViewElementDate;
  final DateTime pageViewMonthDate;

  @override
  Widget build(BuildContext context) {
    return Consumer(
      builder: (BuildContext context, WidgetRef ref, Widget? child) {
        final Widget dateSuitableWidgetProviderValue = ref
            .watch(dateSuitableWidgetProvider(IndividualDateElementProperties(
          pageViewElementDate: pageViewElementDate,
          pageViewMonthDate: pageViewMonthDate,
        )).select((value) => value));

        Widget calendarDateWidget = dateSuitableWidgetProviderValue;
        return calendarDateWidget;
      },
    );
  }
}

Widget getSuitableCalendarDateWidget(
    {required bool enableDenseViewForDates,
    required bool enableDenseSplashForDates,
    required DateTime pageViewElementDate,
    required DateTime pageViewMonthDate,
    required List<DateTime> datesForStreaks,
    required CalendarPropertiesState
        watchCalendarPropertiesStateProviderValue}) {
  if (datesForStreaks.contains(pageViewElementDate)) {
    return getSuitableCalendarStreakDateWidget(
        enableDenseViewForDates: enableDenseViewForDates,
        enableDenseSplashForDates: enableDenseSplashForDates,
        pageViewElementDate: pageViewElementDate,
        pageViewMonthDate: pageViewMonthDate,
        datesForStreaks: datesForStreaks);
  }
  if (!datesForStreaks.contains(pageViewElementDate)) {
    return getSuitableCalendarGeneralDateWidget(
        enableDenseViewForDates: enableDenseViewForDates,
        enableDenseSplashForDates: enableDenseSplashForDates,
        pageViewElementDate: pageViewElementDate,
        pageViewMonthDate: pageViewMonthDate,
        watchCalendarPropertiesStateProviderValue:
            watchCalendarPropertiesStateProviderValue);
  } else {
    return const SizedBox();
  }
}
